---
title: From distance
---

## List of features

::: gentropy.dataset.l2g_features.distance.DistanceSentinelTssFeature
::: gentropy.dataset.l2g_features.distance.DistanceSentinelTssNeighbourhoodFeature
::: gentropy.dataset.l2g_features.distance.DistanceTssMeanFeature
::: gentropy.dataset.l2g_features.distance.DistanceTssMeanNeighbourhoodFeature
::: gentropy.dataset.l2g_features.distance.DistanceSentinelFootprintFeature
::: gentropy.dataset.l2g_features.distance.DistanceSentinelFootprintNeighbourhoodFeature
::: gentropy.dataset.l2g_features.distance.DistanceFootprintMeanFeature
::: gentropy.dataset.l2g_features.distance.DistanceFootprintMeanNeighbourhoodFeature

## Common logic

::: gentropy.dataset.l2g_features.distance.common_distance_feature_logic
::: gentropy.dataset.l2g_features.distance.common_neighbourhood_distance_feature_logic
